==> datadog-api-client-2.2.0-sources.jar: com/datadog/api/client/v2/model/DashboardListAddItemsResponse.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v2.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

/** Response containing a list of added dashboards. */
@JsonPropertyOrder({DashboardListAddItemsResponse.JSON_PROPERTY_ADDED_DASHBOARDS_TO_LIST})
@jakarta.annotation.Generated(
    value = "https://github.com/DataDog/datadog-api-client-java/blob/master/.generator")
public class DashboardListAddItemsResponse {
  @JsonIgnore public boolean unparsed = false;
  public static final String JSON_PROPERTY_ADDED_DASHBOARDS_TO_LIST = "added_dashboards_to_list";
  private List<DashboardListItemResponse> addedDashboardsToList = null;

  public DashboardListAddItemsResponse addedDashboardsToList(
      List<DashboardListItemResponse> addedDashboardsToList) {
    this.addedDashboardsToList = addedDashboardsToList;
    for (DashboardListItemResponse item : addedDashboardsToList) {
      this.unparsed |= item.unparsed;
    }
    return this;
  }

  public DashboardListAddItemsResponse addAddedDashboardsToListItem(
      DashboardListItemResponse addedDashboardsToListItem) {
    if (this.addedDashboardsToList == null) {
      this.addedDashboardsToList = new ArrayList<>();
    }
    this.addedDashboardsToList.add(addedDashboardsToListItem);
    this.unparsed |= addedDashboardsToListItem.unparsed;
    return this;
  }

  /**
   * List of dashboards added to the dashboard list.
   *
   * @return addedDashboardsToList
   */
  @jakarta.annotation.Nullable
  @JsonProperty(JSON_PROPERTY_ADDED_DASHBOARDS_TO_LIST)
  @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
  public List<DashboardListItemResponse> getAddedDashboardsToList() {
    return addedDashboardsToList;
  }

  public void setAddedDashboardsToList(List<DashboardListItemResponse> addedDashboardsToList) {
    this.addedDashboardsToList = addedDashboardsToList;
  }

  /** Return true if this DashboardListAddItemsResponse object is equal to o. */
  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    DashboardListAddItemsResponse dashboardListAddItemsResponse = (DashboardListAddItemsResponse) o;
    return Objects.equals(
        this.addedDashboardsToList, dashboardListAddItemsResponse.addedDashboardsToList);
  }

  @Override
  public int hashCode() {
    return Objects.hash(addedDashboardsToList);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class DashboardListAddItemsResponse {\n");
    sb.append("    addedDashboardsToList: ")
        .append(toIndentedString(addedDashboardsToList))
        .append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}

==> datadog-api-client-2.28.0-sources.jar: com/datadog/api/client/v2/model/DashboardListAddItemsResponse.java <==
/*
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2019-Present Datadog, Inc.
 */

package com.datadog.api.client.v2.model;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;

/** Response containing a list of added dashboards. */
@JsonPropertyOrder({DashboardListAddItemsResponse.JSON_PROPERTY_ADDED_DASHBOARDS_TO_LIST})
@jakarta.annotation.Generated(
    value = "https://github.com/DataDog/datadog-api-client-java/blob/master/.generator")
public class DashboardListAddItemsResponse {
  @JsonIgnore public boolean unparsed = false;
  public static final String JSON_PROPERTY_ADDED_DASHBOARDS_TO_LIST = "added_dashboards_to_list";
  private List<DashboardListItemResponse> addedDashboardsToList = null;

  public DashboardListAddItemsResponse addedDashboardsToList(
      List<DashboardListItemResponse> addedDashboardsToList) {
    this.addedDashboardsToList = addedDashboardsToList;
    for (DashboardListItemResponse item : addedDashboardsToList) {
      this.unparsed |= item.unparsed;
    }
    return this;
  }

  public DashboardListAddItemsResponse addAddedDashboardsToListItem(
      DashboardListItemResponse addedDashboardsToListItem) {
    if (this.addedDashboardsToList == null) {
      this.addedDashboardsToList = new ArrayList<>();
    }
    this.addedDashboardsToList.add(addedDashboardsToListItem);
    this.unparsed |= addedDashboardsToListItem.unparsed;
    return this;
  }

  /**
   * List of dashboards added to the dashboard list.
   *
   * @return addedDashboardsToList
   */
  @jakarta.annotation.Nullable
  @JsonProperty(JSON_PROPERTY_ADDED_DASHBOARDS_TO_LIST)
  @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
  public List<DashboardListItemResponse> getAddedDashboardsToList() {
    return addedDashboardsToList;
  }

  public void setAddedDashboardsToList(List<DashboardListItemResponse> addedDashboardsToList) {
    this.addedDashboardsToList = addedDashboardsToList;
  }

  /**
   * A container for additional, undeclared properties. This is a holder for any undeclared
   * properties as specified with the 'additionalProperties' keyword in the OAS document.
   */
  private Map<String, Object> additionalProperties;

  /**
   * Set the additional (undeclared) property with the specified name and value. If the property
   * does not already exist, create it otherwise replace it.
   *
   * @param key The arbitrary key to set
   * @param value The associated value
   * @return DashboardListAddItemsResponse
   */
  @JsonAnySetter
  public DashboardListAddItemsResponse putAdditionalProperty(String key, Object value) {
    if (this.additionalProperties == null) {
      this.additionalProperties = new HashMap<String, Object>();
    }
    this.additionalProperties.put(key, value);
    return this;
  }

  /**
   * Return the additional (undeclared) property.
   *
   * @return The additional properties
   */
  @JsonAnyGetter
  public Map<String, Object> getAdditionalProperties() {
    return additionalProperties;
  }

  /**
   * Return the additional (undeclared) property with the specified name.
   *
   * @param key The arbitrary key to get
   * @return The specific additional property for the given key
   */
  public Object getAdditionalProperty(String key) {
    if (this.additionalProperties == null) {
      return null;
    }
    return this.additionalProperties.get(key);
  }

  /** Return true if this DashboardListAddItemsResponse object is equal to o. */
  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    DashboardListAddItemsResponse dashboardListAddItemsResponse = (DashboardListAddItemsResponse) o;
    return Objects.equals(
            this.addedDashboardsToList, dashboardListAddItemsResponse.addedDashboardsToList)
        && Objects.equals(
            this.additionalProperties, dashboardListAddItemsResponse.additionalProperties);
  }

  @Override
  public int hashCode() {
    return Objects.hash(addedDashboardsToList, additionalProperties);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class DashboardListAddItemsResponse {\n");
    sb.append("    addedDashboardsToList: ")
        .append(toIndentedString(addedDashboardsToList))
        .append("\n");
    sb.append("    additionalProperties: ")
        .append(toIndentedString(additionalProperties))
        .append("\n");
    sb.append('}');
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces (except the first line).
   */
  private String toIndentedString(Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
